#[non_exhaustive]pub enum Error {
NonMinimalPush,
EarlyEndOfScript,
NumericOverflow,
BitcoinConsensus(Error),
UnknownSpentOutput(OutPoint),
Serialization,
}Expand description
Ways that a script might fail. Not everything is split up as much as it could be; patches welcome if more detailed errors would help you.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonMinimalPush
Something did a non-minimal push; for more information see https://github.com/bitcoin/bips/blob/master/bip-0062.mediawiki#push-operators
EarlyEndOfScript
Some opcode expected a parameter but it was missing or truncated.
NumericOverflow
Tried to read an array off the stack as a number when it was more than 4 bytes.
BitcoinConsensus(Error)
Available on crate feature
bitcoinconsensus only.Error validating the script with bitcoinconsensus library.
UnknownSpentOutput(OutPoint)
Can not find the spent output.
Serialization
Can not serialize the spending transaction.